pari_elldata: PARI data package for elliptic curves
===================================================

Description
-----------

PARI/GP version of J. E. Cremona Elliptic Curve Data, needed by
ellsearch and ellidentify.

License
-------

GNU General Public License (GPL version 2 or any later version).


Upstream Contact
----------------

http://pari.math.u-bordeaux.fr/

Dependencies
------------

-  Installation: None
-  Runtime: PARI/GP
